==> adapters-1.4.0-sources.jar: com/merseyside/adapters/model/SelectableAdapterViewModel.kt <==
package com.merseyside.adapters.model

import androidx.databinding.ObservableBoolean
import androidx.databinding.ObservableField
import com.merseyside.utils.ext.onChange
import com.merseyside.utils.mainThreadIfNeeds

abstract class SelectableAdapterViewModel<M>(
    obj: M,
    private var isSelected: Boolean = IS_SELECTED_DEFAULT,
    private var isSelectable: Boolean = IS_SELECTABLE_DEFAULT
) : ComparableAdapterViewModel<M>(obj) {

    private var isSelectEnabled: Boolean =
        IS_SELECT_ENABLE_DEFAULT

    var selectedObservable = ObservableField(isSelected).apply {
        onChange { _, value, isInitial ->
            if (!isInitial && value != isSelected) {
                onClick()
            }
        }
    }

    var selectableObservable = ObservableBoolean()
    var selectEnabledObservable = ObservableBoolean(isSelectEnabled)

    init {
        setSelectable(isSelectable)
        setSelected(isSelected)
    }

    fun setSelected(isSelected: Boolean, isNotifyItem: Boolean = false) {
        mainThreadIfNeeds {
            this.isSelected = isSelected

            if (isSelectedObservable() != isSelected) {
                this.selectedObservable.set(isSelected)
            }

            if (isNotifyItem) {
                onSelectedChanged(isSelected)
            }
        }
    }

    fun setSelectable(isSelectable: Boolean, isNotifyItem: Boolean = false) {
        mainThreadIfNeeds {
            this.isSelectable = isSelectable

            if (isSelectableObservable() != isSelectable) {
                this.selectableObservable.set(isSelectable)
            }

            if (isNotifyItem) {
                onSelectableChanged(isSelectable)
            }
        }
    }

    fun setSelectEnabled(isSelectEnabled: Boolean, isNotifyItem: Boolean = false) {
        mainThreadIfNeeds {
            this.isSelectEnabled = isSelectEnabled

            if (isSelectEnabledObservable() != isSelectEnabled) {
                this.selectEnabledObservable.set(isSelectEnabled)
            }

            if (isNotifyItem) {
                notifySelectEnabled(isSelectEnabled)
            }
        }
    }

    private fun isSelectedObservable(): Boolean {
        return selectedObservable.get() ?: IS_SELECTED_DEFAULT
    }

    private fun isSelectableObservable(): Boolean {
        return selectableObservable.get()
    }

    private fun isSelectEnabledObservable(): Boolean {
        return selectEnabledObservable.get()
    }

    fun isSelected(): Boolean {
        return isSelected
    }

    fun isSelectable(): Boolean {
        return isSelectable
    }

    /**
     * Notify item isSelectEnabled in adapter has changed.
     */
    abstract fun notifySelectEnabled(isEnabled: Boolean)

    /**
     * Notify item that select state has changed.
     */
    abstract fun onSelectedChanged(isSelected: Boolean)

    /**
     * Notify item that selectable state has changed.
     */
    open fun onSelectableChanged(isSelectable: Boolean) {}

    companion object {
        private const val IS_SELECTED_DEFAULT = false
        private const val IS_SELECTABLE_DEFAULT = true
        private const val IS_SELECT_ENABLE_DEFAULT = true
    }
}

==> adapters-1.5.0-sources.jar: com/merseyside/adapters/model/SelectableAdapterViewModel.kt <==
package com.merseyside.adapters.model

import androidx.databinding.ObservableBoolean
import androidx.databinding.ObservableField
import com.merseyside.utils.ext.onChange
import com.merseyside.utils.mainThreadIfNeeds

abstract class SelectableAdapterViewModel<M>(
    obj: M,
    private var isSelected: Boolean = IS_SELECTED_DEFAULT,
    private var isSelectable: Boolean = IS_SELECTABLE_DEFAULT
) : ComparableAdapterViewModel<M>(obj) {

    private var isSelectEnabled: Boolean =
        IS_SELECT_ENABLE_DEFAULT

    var selectedObservable = ObservableField(isSelected).apply {
        onChange { _, value, isInitial ->
            if (!isInitial && value != isSelected) {
                onClick()
            }
        }
    }

    var selectableObservable = ObservableBoolean()
    var selectEnabledObservable = ObservableBoolean(isSelectEnabled)

    init {
        setSelectable(isSelectable)
        setSelected(isSelected)
    }

    fun setSelected(isSelected: Boolean, notifyItem: Boolean = true) {
        mainThreadIfNeeds {
            this.isSelected = isSelected

            if (isSelectedObservable() != isSelected) {
                this.selectedObservable.set(isSelected)
            }

            if (notifyItem) {
                onSelectedChanged(isSelected)
            }
        }
    }

    fun setSelectable(isSelectable: Boolean, isNotifyItem: Boolean = false) {
        mainThreadIfNeeds {
            this.isSelectable = isSelectable

            if (isSelectableObservable() != isSelectable) {
                this.selectableObservable.set(isSelectable)
            }

            if (isNotifyItem) {
                onSelectableChanged(isSelectable)
            }
        }
    }

    fun setSelectEnabled(isSelectEnabled: Boolean, isNotifyItem: Boolean = false) {
        mainThreadIfNeeds {
            this.isSelectEnabled = isSelectEnabled

            if (isSelectEnabledObservable() != isSelectEnabled) {
                this.selectEnabledObservable.set(isSelectEnabled)
            }

            if (isNotifyItem) {
                notifySelectEnabled(isSelectEnabled)
            }
        }
    }

    private fun isSelectedObservable(): Boolean {
        return selectedObservable.get() ?: IS_SELECTED_DEFAULT
    }

    private fun isSelectableObservable(): Boolean {
        return selectableObservable.get()
    }

    private fun isSelectEnabledObservable(): Boolean {
        return selectEnabledObservable.get()
    }

    fun isSelected(): Boolean {
        return isSelected
    }

    fun isSelectable(): Boolean {
        return isSelectable
    }

    /**
     * Notify item isSelectEnabled in adapter has changed.
     */
    abstract fun notifySelectEnabled(isEnabled: Boolean)

    /**
     * Notify item that select state has changed.
     */
    abstract fun onSelectedChanged(isSelected: Boolean)

    /**
     * Notify item that selectable state has changed.
     */
    open fun onSelectableChanged(isSelectable: Boolean) {}

    companion object {
        private const val IS_SELECTED_DEFAULT = false
        private const val IS_SELECTABLE_DEFAULT = true
        private const val IS_SELECT_ENABLE_DEFAULT = true
    }
}
